==> openj9-18_0.33.1.orig.tar.xz: src-openj9-18-0.33.1/openj9/test/functional/VM_Test/src/com/ibm/j9/monitor/tests/TestNatives.java <==
package com.ibm.j9.monitor.tests;

/*******************************************************************************
 * Copyright (c) 2008, 2012 IBM Corp. and others
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution and
 * is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] http://openjdk.java.net/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0 WITH Classpath-exception-2.0 OR LicenseRef-GPL-2.0 WITH Assembly-exception
 *******************************************************************************/

public class TestNatives {
	static final String NATIVE_LIBRARY_NAME = "j9thrtestnatives" + System.getProperty("com.ibm.oti.vm.library.version");
	static boolean libraryLoaded = false;
	
	/**
	 * make sure the native library required to run the natives is loaded
	 */
	public static void ensureLibraryLoaded(){
		if (libraryLoaded == false){
			System.loadLibrary(NATIVE_LIBRARY_NAME);
			libraryLoaded = true;
		}
	}
	
	/**
	 * constructor
	 */	
	public TestNatives() {
		ensureLibraryLoaded();
	}
	
	public static long getHeaderSizeWrapper() {
		ensureLibraryLoaded();
		return getHeaderSize();
	}
	
	public native long getLockWordValue(Object obj); 
	public native long getLockWordOffset(Object obj);
	public static native long getHeaderSize();
	public static native long getLockwordSize();

}

==> openj9-21_0.56.0.orig.tar.xz: src-openj9-21-0.56.0/openj9/test/functional/VM_Test/src/com/ibm/j9/monitor/tests/TestNatives.java <==
package com.ibm.j9.monitor.tests;

/*
 * Copyright IBM Corp. and others 2008
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution and
 * is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */

public class TestNatives {
	static final String NATIVE_LIBRARY_NAME = "j9thrtestnatives" + System.getProperty("com.ibm.oti.vm.library.version");
	static boolean libraryLoaded = false;
	
	/**
	 * make sure the native library required to run the natives is loaded
	 */
	public static void ensureLibraryLoaded(){
		if (libraryLoaded == false){
			System.loadLibrary(NATIVE_LIBRARY_NAME);
			libraryLoaded = true;
		}
	}
	
	/**
	 * constructor
	 */	
	public TestNatives() {
		ensureLibraryLoaded();
	}
	
	public static long getHeaderSizeWrapper() {
		ensureLibraryLoaded();
		return getHeaderSize();
	}
	
	public native long getLockWordValue(Object obj); 
	public native long getLockWordOffset(Object obj);
	public static native long getHeaderSize();
	public static native long getLockwordSize();

}
